SandboxExecutionEnvironment

Struct SandboxExecutionEnvironment 

pub struct SandboxExecutionEnvironment { /* private fields */ }
Execution environment backed by a long-lived sandbox provider JSONL process.

Implementations

Source

impl SandboxExecutionEnvironment

pub async fn open( program: impl Into<PathBuf>, request: OpenSandboxRequest, ) -> Result<Self>

Start program serve, open a sandbox session, and wrap it as an execution environment.

pub fn from_session( client: Arc<SandboxProviderJsonlClient>, session: SandboxSession, ) -> Self

pub fn client(&self) -> &Arc<SandboxProviderJsonlClient>

pub fn session(&self) -> &SandboxSession

pub async fn close(self) -> Result<()>

Close the sandbox session and ask the provider to shut down.